@@ -8,9 +8,9 @@
 import gi
 gi.require_version('GMime', '3.0')
 from gi.repository import GMime
-GMime.init(0)
+GMime.init()
 
-f = GMime.StreamFile.new_for_path('/usr/share/doc/gir1.2-gmime-3.0/examples/example.eml', 'r')
+f = GMime.StreamFile.open('/usr/share/doc/gir1.2-gmime-3.0/examples/example.eml', 'r')
 parser = GMime.Parser.new_with_stream(f)
 msg = parser.construct_message()
 
